CPSolver.Examples.BinPacking.Search (Fixpoint v0.20.2)
Link to this section Summary
Functions
Complete decreasing best fit branching, roughly as per https://www.gecode.dev/doc-latest/MPG.pdf, chapter 20
Link to this section Functions
Link to this function
cdbf(item_weights, item_assignment_vars, bin_load_vars, capacity)
Complete decreasing best fit branching, roughly as per https://www.gecode.dev/doc-latest/MPG.pdf, chapter 20