CPSolver.Examples.BinPacking (Fixpoint v0.20.2)
Bin Packing Problem Example
Given:
- n: items, each with weights w[i]
- b: max. bin capacity
The goal is to assign each item to a bin such that: Sum of item weights in each bin <= capacity and the number of bins used is minimized.
Link to this section Summary
Link to this section Functions
Link to this function
check_solution(result, item_weights, capacity)
Link to this function
check_solution(solution, item_weights, capacity, variable_names)
Link to this function
minimization_model(item_weights, capacity, upper_bound \\ nil)
Link to this function
model(item_weights, capacity, upper_bound, type \\ :minimize)
Link to this function
solution_handler()
Link to this function
solution_to_bin_content(item_assignments, item_weights)
Link to this function